Applies Rubin's rules to combine estimates and variance-covariance matrices from different imputations.
combine_rubin(param_imps, cov_imps)A list:
Vector of combined parameter estimates with the same length
as columns in param_imps.
Combined variance-covariance matrix of size n x n, where n
is the number of columns in param_imps.
Between imputations variance-covariance matrix of size
n x n, where n is the number of columns in param_imps.
Matrix containing estimated parameters in each imputation as its rows.
List of estimated covariance matrices for each imputation.
Rubin D. B. Multiple imputation for nonresponse in surveys (2004). John Wiley & Sons.